@@ -18,15 +18,9 @@
 #
 """
 Main SchoolTool script.
-
-This module is not necessary if you use SchoolTool as a Zope 3 content object.
-It is only used by the standalone SchoolTool executable.
-
-$Id$
 """
 import os
 import sys
-import time
 import getopt
 import locale
 import gettext
@@ -46,12 +40,9 @@ from zope.interface import directlyProvides, implements
 from zope.component import provideUtility
 from zope.component import provideAdapter, adapts
 from zope.event import notify
-from zope.server.taskthreads import ThreadedTaskDispatcher
 from zope.publisher.interfaces.http import IHTTPRequest
 from zope.i18n.interfaces import IUserPreferredLanguages
-from zope.app.server.main import run
-from zope.app.server.wsgi import http
-from zope.app.appsetup import DatabaseOpened, ProcessStarting
+from zope.app.appsetup import DatabaseOpened
 from zope.app.publication.zopepublication import ZopePublication
 from zope.traversing.interfaces import IContainmentRoot
 from zope.lifecycleevent import ObjectAddedEvent
@@ -92,22 +83,11 @@ _._domain = 'schooltool'
 
 
 class Options(object):
-    config_filename = 'schooltool.conf'
-    daemon = False
-    quiet = False
     config = None
     pack = False
     restore_manager = False
     manager_password = MANAGER_PASSWORD
-    manage = False
-
-    def __init__(self):
-        dirname = os.path.dirname(__file__)
-        dirname = os.path.normpath(os.path.join(dirname, '..', '..', '..'))
-        self.config_file = os.path.join(dirname, self.config_filename)
-        if not os.path.exists(self.config_file):
-            self.config_file = os.path.join(dirname,
-                                            self.config_filename + '.in')
+    config_file = ''
 
 
 class CookieLanguageSelector(object):
@@ -292,27 +272,6 @@ def setUpLogger(name, filenames, format=None):
         logger.addHandler(handler)
 
 
-def daemonize():
-    """Daemonize with a double fork and close the standard IO."""
-    pid = os.fork()
-    if pid:
-        sys.exit(0)
-    os.setsid()
-    os.umask(077)
-
-    pid = os.fork()
-    if pid:
-        print _("Going to background, daemon pid %d") % pid
-        sys.exit(0)
-
-    os.close(0)
-    os.close(1)
-    os.close(2)
-    os.open('/dev/null', os.O_RDWR)
-    os.dup(0)
-    os.dup(0)
-
-
 class PluginDependency(object):
 
     def __init__(self, plugin, name,
@@ -496,7 +455,7 @@ class SchoolToolServer(object):
         try:
             opts, args = getopt.gnu_getopt(argv[1:], 'c:hdr:',
                                            ['config=', 'pack',
-                                            'help', 'daemon',
+                                            'help',
                                             'restore-manager=',
                                             'manage'])
         except getopt.error, e:
@@ -505,42 +464,30 @@ class SchoolToolServer(object):
             sys.exit(1)
         for k, v in opts:
             if k in ('-h', '--help'):
-                print _("\n"
+                print (_("\n"
                         "Usage: %s [options]\n"
                         "Options:\n"
-                        "  -c, --config xxx       use this configuration file instead of the default\n"
+                        "  -c, --config xxx       use this configuration file\n"
                         "  -h, --help             show this help message\n"
-                        "  -d, --daemon           go to background after starting\n"
                         "  --pack                 pack the database\n"
                         "  -r, --restore-manager password\n"
                         "                         restore the manager user with the provided password\n"
                         "                         (read password from the standart input if 'password'\n"
                         "                         is '-')\n"
-                        % progname).strip()
+                        ) % progname).strip()
                 sys.exit(0)
             if k in ('-c', '--config'):
                 options.config_file = v
             if k in ('-p', '--pack'):
                 options.pack = True
-                options.manage = True
-            if k in ('-d', '--daemon'):
-                if not hasattr(os, 'fork'):
-                    print >> sys.stderr, _("%s: daemon mode not supported on "
-                                           "your operating system.") % progname
-                    sys.exit(1)
-                else:
-                    options.daemon = True
             if k in ('-r', '--restore-manager'):
                 options.restore_manager = True
                 if v != '-':
                     options.manager_password = v
                 else:
-                    print 'Manager password: ',
-                    password = sys.stdin.readline().strip('\r\n')
+                    from getpass import getpass
+                    password = getpass(_("Manager password: "))
                     options.manager_password = password
-                options.manage = True
-            if k in ('--manage'):
-                options.manage = True
 
         # Read configuration file
         schema_string = open(self.ZCONFIG_SCHEMA).read()
@@ -549,6 +496,10 @@ class SchoolToolServer(object):
         schema_string = schema_string % {'plugins': "\n".join(plugins)}
         schema_file = StringIO(schema_string)
 
+        if not options.config_file:
+            print >> sys.stderr, _("No configuration file given")
+            sys.exit(1)
+
         schema = ZConfig.loadSchemaFile(schema_file, self.ZCONFIG_SCHEMA)
 
         print _("Reading configuration from %s") % options.config_file
@@ -559,17 +510,14 @@ class SchoolToolServer(object):
             print >> sys.stderr, "%s: %s" % (progname, e)
             sys.exit(1)
         if options.config.database.config.storage is None:
-            print >> sys.stderr, "%s: %s" % (progname, _("\n"
-                "No storage defined in the configuration file.\n"
-                "\n"
-                "If you're using the default configuration file, please edit it now and\n"
-                "uncomment one of the ZODB storage sections.\n").strip())
+            print >> sys.stderr, "%s: %s" % (progname, _(
+                "No storage defined in the configuration file."))
 
             sys.exit(1)
 
         return options
 
-    def bootstrapSchoolTool(self, db, school_type=""):
+    def bootstrapSchoolTool(self, db):
         """Bootstrap SchoolTool database."""
         connection = db.open()
         root = connection.root()
@@ -579,7 +527,7 @@ class SchoolToolServer(object):
 
             # Run school specific initialization code
             initializationUtility = getUtility(
-                ISchoolToolInitializationUtility, name=school_type)
+                ISchoolToolInitializationUtility)
             initializationUtility.initializeApplication(app)
 
             directlyProvides(app, directlyProvidedBy(app) + IContainmentRoot)
@@ -635,7 +583,6 @@ class SchoolToolServer(object):
         transaction.commit()
         connection.close()
 
-
     def restoreManagerUser(self, app, password):
         """Ensure there is a manager user
 
@@ -689,7 +636,7 @@ class SchoolToolServer(object):
                                        " is using it?") % self.system_name
             sys.exit(1)
 
-        self.bootstrapSchoolTool(db, options.config.school_type)
+        self.bootstrapSchoolTool(db)
         notify(DatabaseOpened(db))
 
         if options.restore_manager:
@@ -700,6 +647,9 @@ class SchoolToolServer(object):
             transaction.commit()
             connection.close()
 
+        if options.pack or options.restore_manager:
+            return db
+
         self.startApplication(db)
 
         provideUtility(db, IDatabase)
@@ -716,13 +666,6 @@ class SchoolToolServer(object):
         if not fontdirs:
             return
 
-        try:
-            import reportlab
-        except ImportError:
-            print >> sys.stderr, _("Warning: could not find the reportlab"
-                                   " library.\nPDF support disabled.")
-            return
-
         existing_directories = []
         for fontdir in fontdirs.split(':'):
             if os.path.isdir(fontdir):
@@ -749,46 +692,13 @@ class SchoolToolServer(object):
 
         pdf.setUpFonts(existing_directories)
 
-        
-class StandaloneServer(SchoolToolServer):
-    
-    def beforeRun(self, options, db):
-        if options.daemon:
-            daemonize()
-
-        task_dispatcher = ThreadedTaskDispatcher()
-        task_dispatcher.setThreadCount(options.config.thread_pool_size)
-
-        for ip, port in options.config.web:
-            server = http.create('HTTP', task_dispatcher, db, port=port, ip=ip)
-
-        notify(ProcessStarting())
-
-        if options.config.pid_file:
-            pidfile = file(options.config.pid_file, "w")
-            print >> pidfile, os.getpid()
-            pidfile.close()
-
     def main(self, argv=sys.argv):
-        """Start the SchoolTool server."""
-        t0, c0 = time.time(), time.clock()
         options = self.load_options(argv)
         db = self.setup(options)
-        if not options.manage:
-            self.beforeRun(options, db)
-            t1, c1 = time.time(), time.clock()
-            print _("Startup time: %.3f sec real, %.3f sec CPU") % (t1 - t0,
-                                                                    c1 - c0)
-            run()
-            self.afterRun(options)
-
-    def afterRun(self, options):
-        if options.config.pid_file:
-            os.unlink(options.config.pid_file)
 
 
 def main():
-    StandaloneServer().main()
+    SchoolToolServer().main()
 
 if __name__ == '__main__':
     main()
