@@ -34,20 +34,6 @@ here = os.path.dirname(__file__)
 ftesting_zcml = os.path.join(here, '..', 'ftesting.zcml')
 
 
-def doctest_Options():
-    """Tests for Options.
-
-    The only interesting thing Options does is find the default configuration
-    file.
-
-        >>> from schooltool.app.main import Options
-        >>> options = Options()
-        >>> options.config_file
-        '...schooltool.conf...'
-
-    """
-
-
 def doctest_main():
     """Tests for main().
 
@@ -60,7 +46,7 @@ def doctest_main():
         >>> from schooltool.app.main import Options
         >>> options = Options()
         >>> class ConfigStub:
-        ...     pid_file = ''
+        ...     pass
         >>> options.config = ConfigStub()
 
         >>> def load_options_stub(argv):
@@ -68,34 +54,16 @@ def doctest_main():
         >>> def setup_stub(opts):
         ...     print "Performing setup..."
         ...     assert opts is options
-        >>> def run_stub():
-        ...     print "Running..."
-        >>> def before_run_stub(options, db):
-        ...     print "before Running..."
-        >>> def after_run_stub(options):
-        ...     print "after Running..."
-        >>> from schooltool.app import main
-        >>> from schooltool.app.main import StandaloneServer
-        >>> server = StandaloneServer()
-        >>> old_run = main.run
+        >>> from schooltool.app.main import SchoolToolServer
+        >>> server = SchoolToolServer()
         >>> server.load_options = load_options_stub
         >>> server.setup = setup_stub
-        >>> server.beforeRun = before_run_stub
-        >>> server.afterRun = after_run_stub
-        >>> main.run = run_stub
 
     Now we will run main().
 
-        >>> server.main(['sb.py', '-d'])
+        >>> server.main(['sb.py'])
         Performing setup...
-        before Running...
-        Startup time: ... sec real, ... sec CPU
-        Running...
-        after Running...
 
-    Clean up
-
-        >>> main.run = old_run
     """
 
 
@@ -122,8 +90,8 @@ def doctest_load_options():
 
     Load options parses command line arguments and the configuration file.
 
-        >>> from schooltool.app.main import StandaloneServer
-        >>> server = StandaloneServer()
+        >>> from schooltool.app.main import SchoolToolServer
+        >>> server = SchoolToolServer()
         >>> o = server.load_options(['st.py', '-c', sample_config_file])
         Reading configuration from ...sample.conf
 
@@ -131,19 +99,17 @@ def doctest_load_options():
 
         >>> o.config_file
         '...sample.conf'
-        >>> o.daemon
+        >>> o.pack
         False
 
     Some come from the config file
 
-        >>> o.config.web in ([('', 48080)],          # Unix
-        ...                  [('localhost', 48080)]) # Windows
-        True
-        >>> o.config.listen
-        [('...', 123), ('10.20.30.40', 9999)]
-
-    Note that "listen 123" in config.py produces ('localhost', 123) on
-    Windows, but ('', 123) on other platforms.
+        >>> o.config.error_log_file
+        ['/var/log/schooltool/schooltool.log', 'STDERR']
+        >>> o.config.web_access_log_file
+        ['/var/log/schooltool/web-access.log']
+        >>> o.config.reportlab_fontdir
+        '/fonts/liberation:/fonts/ubuntu'
 
     `load_options` can also give you a nice help message and exit with status
     code 0.
@@ -154,9 +120,8 @@ def doctest_load_options():
         ...     print '[exited with status %s]' % e
         Usage: st.py [options]
         Options:
-          -c, --config xxx       use this configuration file instead of the default
+          -c, --config xxx       use this configuration file
           -h, --help             show this help message
-          -d, --daemon           go to background after starting
           --pack                 pack the database
           -r, --restore-manager password
                                  restore the manager user with the provided password
@@ -193,9 +158,6 @@ def doctest_load_options():
         ...     print '[exited with status %s]' % e
         Reading configuration from ...empty.conf
         st.py: No storage defined in the configuration file.
-        <BLANKLINE>
-        If you're using the default configuration file, please edit it now and
-        uncomment one of the ZODB storage sections.
         [exited with status 1]
 
     Cleaning up.
@@ -211,49 +173,23 @@ def doctest_configureReportlab():
     """Tests for configureReportlab.
 
         >>> from schooltool.app import pdf
-        >>> from schooltool.app.main import StandaloneServer
+        >>> from schooltool.app.main import SchoolToolServer
 
-        >>> server = StandaloneServer()
+        >>> server = SchoolToolServer()
 
         >>> def setupStub(fontdir):
         ...     print 'reportlab set up: %s' % fontdir
         >>> realSetup = pdf.setUpFonts
         >>> pdf.setUpFonts = setupStub
 
+        >>> old_stderr = sys.stderr
+        >>> sys.stderr = sys.stdout
+
     First, if a null path is given, nothing happens (PDF support is
     left disabled):
 
         >>> server.configureReportlab(None)
 
-    Now, let's imitate a situation where a font path is given, but reportlab
-    can not be imported.
-
-        >>> old_stderr = sys.stderr
-        >>> sys.stderr = sys.stdout
-
-        >>> try:
-        ...     import reportlab
-        ... except ImportError:
-        ...     pass
-
-        >>> real_reportlab = sys.modules.get('reportlab')
-        >>> sys.modules['reportlab'] = None
-
-    reportlab can not be imported, see?
-
-        >>> import reportlab
-        Traceback (most recent call last):
-          ...
-        ImportError: No module named reportlab
-
-    Good.  Now configureReportLab should print a warning.
-
-        >>> server.configureReportlab('.')
-        Warning: could not find the reportlab library.
-        PDF support disabled.
-
-        >>> sys.modules['reportlab'] = object()
-
     Now test the check that the font path is a directory:
 
         >>> server.configureReportlab(__file__)
@@ -280,8 +216,6 @@ def doctest_configureReportlab():
 
         >>> pdf.font_map = real_font_map
         >>> sys.stderr = old_stderr
-        >>> if real_reportlab:
-        ...     sys.modules['reportlab'] = real_reportlab
         >>> pdf.setUpFonts = realSetup
 
     """
@@ -347,7 +281,7 @@ def doctest_setup():
 
     It is difficult to unit test, but we'll try.
 
-        >>> from schooltool.app.main import Options, StandaloneServer
+        >>> from schooltool.app.main import Options, SchoolToolServer
         >>> from ZODB.MappingStorage import MappingStorage
         >>> from ZODB.DB import DB
         >>> options = Options()
@@ -355,19 +289,15 @@ def doctest_setup():
         ...     def open(self):
         ...         return DB(MappingStorage())
         >>> class ConfigStub:
-        ...     web = []
-        ...     listen = []
         ...     thread_pool_size = 1
         ...     database = DatabaseConfigStub()
         ...     pid_file = ''
-        ...     path = []
         ...     error_log_file = ['STDERR']
         ...     web_access_log_file = ['STDOUT']
         ...     attendance_log_file = ['STDOUT']
         ...     lang = 'lt'
         ...     reportlab_fontdir = ''
         ...     devmode = False
-        ...     school_type = ''
         ...     site_definition = ftesting_zcml
         >>> options.config = ConfigStub()
 
@@ -378,7 +308,7 @@ def doctest_setup():
 
     And go!
 
-        >>> server = StandaloneServer()
+        >>> server = SchoolToolServer()
         >>> db = server.setup(options)
         >>> print db
         <ZODB.DB.DB object at ...>
@@ -441,48 +371,6 @@ def doctest_setup():
     """
 
 
-def doctest_before_afterRun():
-    """Tests for beforeRun(options, db) and afterRun(options)
-
-        >>> from zope.app.testing import setup
-        >>> setup.placelessSetUp()
-
-    beforeRun(options, db) starts tcp server
-
-        >>> from schooltool.app.main import Options, StandaloneServer
-        >>> from ZODB.MappingStorage import MappingStorage
-        >>> from ZODB.DB import DB
-        >>> options = Options()
-        >>> class DatabaseConfigStub:
-        ...     def open(self):
-        ...         return DB(MappingStorage())
-        >>> class ConfigStub:
-        ...     web = []
-        ...     listen = []
-        ...     thread_pool_size = 1
-        ...     database = DatabaseConfigStub()
-        ...     pid_file = ''
-        ...     path = []
-        ...     error_log_file = ['STDERR']
-        ...     web_access_log_file = ['STDOUT']
-        ...     attendance_log_file = ['STDOUT']
-        ...     lang = 'lt'
-        ...     reportlab_fontdir = ''
-        ...     devmode = False
-        ...     site_definition = ftesting_zcml
-        >>> options.config = ConfigStub()
-        >>> db = object()
-
-    And go!
-
-        >>> server = StandaloneServer()
-        >>> server.beforeRun(options, db)
-        >>> server.afterRun(options)
-
-        >>> setup.placelessTearDown()
-
-    """
-
 
 class ConfigStub(object):
 
@@ -501,8 +389,8 @@ def doctest_bootstrapSchoolTool():
 
     Normally, bootstrapSchoolTool is called when Zope 3 is fully configured
 
-        >>> from schooltool.app.main import StandaloneServer
-        >>> server = StandaloneServer()
+        >>> from schooltool.app.main import SchoolToolServer
+        >>> server = SchoolToolServer()
         >>> server.siteConfigFile = ftesting_zcml
         >>> server.configure(OptionsStub())
 
@@ -572,14 +460,14 @@ def doctest_bootstrapSchoolTool():
 
 
 def doctest_restoreManagerUser():
-    r"""Unit test for StandaloneServer.restoreManagerUser
+    r"""Unit test for SchoolToolServer.restoreManagerUser
 
         >>> cleanup.setUp()
 
     We need a configured server:
 
-        >>> from schooltool.app.main import StandaloneServer
-        >>> server = StandaloneServer()
+        >>> from schooltool.app.main import SchoolToolServer
+        >>> server = SchoolToolServer()
         >>> server.siteConfigFile = ftesting_zcml
         >>> server.configure(OptionsStub())
 
