@@ -19,8 +19,6 @@
 """
 Basic person browser views.
 """
-from time import mktime
-from datetime import datetime
 
 from zope.interface import Interface, implements
 from zope.container.interfaces import INameChooser
@@ -29,26 +27,19 @@ from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile
 from zope.cachedescriptors.property import Lazy
 from zope.component import adapts
 from zope.component import getUtility, queryMultiAdapter, getMultiAdapter
-from zope.datetime import time, rfc1123_date
-from zope.dublincore.interfaces import IZopeDublinCore
 from zope.i18n import translate
 from z3c.form import form, field, button, validator
 from z3c.form.interfaces import DISPLAY_MODE
 from zope.interface import invariant, Invalid
-from zope.publisher.interfaces import NotFound
-from zope.publisher.browser import BrowserPage
-from zope.schema import Password, TextLine, Choice, List, Object
+from zope.schema import Password, TextLine, Choice, List
 from zope.schema import ValidationError
-from zope.schema.interfaces import ITitledTokenizedTerm, IField
+from zope.schema.interfaces import ITitledTokenizedTerm
 from zope.traversing.browser.absoluteurl import absoluteURL
-from zope.viewlet.viewlet import ViewletBase
 from zope.security.checker import canAccess
 
-from reportlab.lib import pagesizes
 from reportlab.lib import units
 import z3c.form.interfaces
 from z3c.form.validator import SimpleFieldValidator
-import zc.table.table
 
 from schooltool.app.browser.app import RelationshipViewBase
 from schooltool.app.browser.app import EditRelationships
@@ -68,7 +59,7 @@ from schooltool.group.interfaces import IGroupContainer
 from schooltool.person.interfaces import IPerson, IPersonFactory
 from schooltool.person.browser.person import PersonTable, PersonTableFormatter
 from schooltool.person.browser.person import PersonTableFilter
-from schooltool.schoolyear.interfaces import ISchoolYearContainer, ISchoolYear
+from schooltool.schoolyear.interfaces import ISchoolYearContainer
 from schooltool.skin.containers import TableContainerView
 from schooltool.skin import flourish
 from schooltool.skin.flourish.interfaces import IViewletManager
@@ -76,9 +67,8 @@ from schooltool.skin.flourish.form import FormViewlet
 from schooltool.skin.flourish.viewlet import Viewlet, ViewletManager
 from schooltool.skin.flourish.content import ContentProvider
 from schooltool.table import table
-from schooltool.table.interfaces import ITableFormatter
 from schooltool.table.catalog import IndexedLocaleAwareGetterColumn
-from schooltool.table.interfaces import IIndexedColumn
+from schooltool.term.interfaces import IDateManager
 from schooltool.report.browser.report import RequestReportDownloadDialog
 
 from schooltool.common import SchoolToolMessage as _
@@ -959,14 +949,14 @@ class FlourishPersonAddView(PersonAddViewBase):
                 _('Full Name'),
                 ['prefix', 'first_name', 'middle_name', 'last_name',
                  'suffix', 'preferred_name']),
+            'user': (
+                _('User'), ['username', 'password', 'confirm']),
             'details': (
                 _('Details'), ['gender', 'birth_date', 'photo']),
             'demographics': (
                 _('Demographics'), list(self.getDemoFields())),
             'relationships': (
                 _('Relationships'), relationship_fields),
-            'user': (
-                _('User'), ['username', 'password', 'confirm']),
             }
         self.fieldset_order = (
             'full_name', 'details', 'demographics',
@@ -1099,16 +1089,10 @@ class BasicPersonTableFormatter(PersonTableFormatter):
             subsort=True)
         return cols + [username]
 
-    def render(self):
-        columns = [IIndexedColumn(c) for c in self._columns]
-        formatter = self._table_formatter(
-            self.context, self.request, self._items,
-            columns=columns,
-            batch_start=self.batch.start, batch_size=self.batch.size,
-            sort_on=self._sort_on,
-            prefix=self.prefix)
+    def makeFormatter(self):
+        formatter = PersonTableFormatter.makeFormatter(self)
         formatter.cssClasses['table'] = 'data persons-table'
-        return formatter()
+        return formatter
 
 
 class FlourishManagePeopleOverview(flourish.page.Content):
@@ -1158,6 +1142,12 @@ class FlourishRequestPersonIDCardView(RequestReportDownloadDialog):
         return absoluteURL(self.context, self.request) + '/person_id_card.pdf'
 
 
+class FlourishRequestPersonProfileView(RequestReportDownloadDialog):
+
+    def nextURL(self):
+        return absoluteURL(self.context, self.request) + '/person_profile.pdf'
+
+
 class IDCardsPageTemplate(DefaultPageTemplate):
 
     template = ViewPageTemplateFile('templates/f_id_cards_template.pt',
@@ -1372,3 +1362,68 @@ class PhotoView(flourish.widgets.ImageView):
 class PersonContainerViewTableFilter(PersonTableFilter):
 
     template = ViewPageTemplateFile('templates/f_container_table_filter.pt')
+
+
+class PersonProfilePDF(flourish.report.PlainPDFPage):
+
+    name = _("Profile")
+
+    def formatDate(self, date, format='mediumDate'):
+        if date is None:
+            return ''
+        formatter = getMultiAdapter((date, self.request), name=format)
+        return formatter()
+
+    @property
+    def scope(self):
+        dtm = getUtility(IDateManager)
+        today = dtm.today
+        return self.formatDate(today)
+
+    @property
+    def subtitles_left(self):
+        student_id = _('Username: ${username}',
+                       mapping={'username': self.context.username})
+        subtitles = [
+            student_id,
+            ]
+        return subtitles
+
+    @property
+    def title(self):
+        return self.context.title
+
+    @property
+    def base_filename(self):
+        return '%s_%s_%s' % (
+            self.context.last_name,  self.context.first_name, self.context.username)
+
+
+class ProfileGeneralPart(flourish.report.PDFForm):
+
+    title = _("General Information")
+
+    def getFields(self):
+        field_descriptions = IDemographicsFields(ISchoolToolApplication(None))
+        fields = field.Fields()
+        for field_desc in field_descriptions.values():
+            fields += field_desc.makeField()
+        return fields
+
+    def update(self):
+        self.fields = field.Fields(IBasicPerson)
+        self.fields += field.Fields(IPhotoField)
+        self.fields += field.Fields(IPerson).select('username')
+        self.fields += self.getFields()
+        super(ProfileGeneralPart, self).update()
+
+
+class UserLinkViewlet(flourish.page.LinkViewlet):
+
+    @property
+    def url(self):
+        user = IPerson(self.request.principal, None)
+        link = self.link
+        if not link or user is None:
+            return None
+        return "%s/%s" % (absoluteURL(user, self.request), self.link)
