@@ -35,6 +35,8 @@ from schooltool.table.batch import TokenBatch
 from schooltool.table.table import TableContent, FilterWidget
 from schooltool.table.table import url_cell_formatter
 from schooltool.table.table import SortUIHeaderMixin
+from schooltool.table.table import HeaderFormatterMixin
+from schooltool.table.table import StandaloneHeaderFormatterMixin
 from schooltool.table.catalog import IndexedTableFormatter
 from schooltool.table.catalog import IndexedFilterWidget
 from schooltool.common import SchoolToolMessage as _
@@ -56,12 +58,14 @@ class AJAXSortHeaderMixin(SortUIHeaderMixin):
         return template % options
 
 
-class AJAXFormSortFormatter(AJAXSortHeaderMixin,
+class AJAXFormSortFormatter(HeaderFormatterMixin,
+                            AJAXSortHeaderMixin,
                             table.FormSortFormatter):
     script_name = 'ST.table.on_form_sort'
 
 
-class AJAXStandaloneSortFormatter(AJAXSortHeaderMixin,
+class AJAXStandaloneSortFormatter(StandaloneHeaderFormatterMixin,
+                                  AJAXSortHeaderMixin,
                                   table.StandaloneSortFormatter):
     script_name = 'ST.table.on_standalone_sort'
 
@@ -108,20 +112,26 @@ class Table(flourish.ajax.CompositeAJAXPart, TableContent):
         TableContent.update(self)
         flourish.ajax.CompositeAJAXPart.update(self)
 
-    def renderTable(self):
+    def makeFormatter(self):
         if self._table_formatter is None:
-            return ''
+            return None
         formatter = self._table_formatter(
             self.source, self.request, self._items,
+            visible_column_names=self.visible_column_names,
             columns=self._columns,
             batch_start=self.batch.start, batch_size=self.batch.size,
             sort_on=self._sort_on,
             prefix=self.prefix,
             ignore_request=self.ignoreRequest,
+            group_by_column=self.group_by_column,
             )
         formatter.html_id = self.html_id
         formatter.cssClasses.update(self.css_classes)
-        return formatter()
+        return formatter
+
+    def renderTable(self):
+        formatter = self.makeFormatter()
+        return formatter() if formatter is not None else ''
 
     def render(self, *args, **kw):
         content = ''
@@ -275,7 +285,7 @@ class IndexedTable(IndexedTableFormatter, Table):
     def filter_widget(self):
         return self.get('filter')
 
-    def renderTable(self):
+    def makeFormatter(self):
         if self._table_formatter is None:
             return ''
         columns = [IIndexedColumn(c) for c in self._columns]
@@ -284,10 +294,13 @@ class IndexedTable(IndexedTableFormatter, Table):
             columns=columns,
             batch_start=self.batch.start, batch_size=self.batch.size,
             sort_on=self._sort_on,
-            prefix=self.prefix)
+            prefix=self.prefix,
+            group_by_column=self.group_by_column)
         formatter.html_id = self.html_id
         formatter.cssClasses.update(self.css_classes)
-        return formatter()
+        return formatter
+
+    renderTable = Table.renderTable
 
     def render(self, *args, **kw):
         return Table.render(self, *args, **kw)
