@@ -51,7 +51,6 @@ def find_ftesting_zcml():
 class ZCMLLayer(_ZCMLLayer):
 
     def __init__(self, *args, **kwargs):
-        self.school_type = kwargs.pop("school_type", "")
         kwargs['allow_teardown'] = True
         _ZCMLLayer.__init__(self, *args, **kwargs)
 
@@ -72,12 +71,13 @@ class ZCMLLayer(_ZCMLLayer):
             """Remove schooltool_db_setup from zope.event.subscribers."""
             zope.event.subscribers.remove(schooltool_db_setup)
 
-        def schooltool_db_setup(event, school_type=""):
+        def schooltool_db_setup(event):
             """IDatabaseOpenedEvent handler that bootstraps SchoolTool."""
             if IDatabaseOpenedEvent.providedBy(event):
                 import schooltool.app.main
-                server = schooltool.app.main.StandaloneServer()
-                server.bootstrapSchoolTool(event.database, self.school_type)
+                server = schooltool.app.main.SchoolToolServer()
+                server.bootstrapSchoolTool(event.database)
+                server.startApplication(event.database)
 
         install_db_bootstrap_hook()
         try:
@@ -147,16 +147,19 @@ def collect_txt_ftests(package=None, level=None, layer=None, filenames=None,
     return unittest.TestSuite(suites)
 
 
-def collect_ftests(package=None, level=None, layer=None, filenames=None):
+def collect_ftests(package=None, level=None, layer=None, filenames=None,
+                   extra_globs=None):
     package = doctest._normalize_module(package)
+    extra_globs = extra_globs or {}
+    extra_globs.update({'analyze': analyze,
+                        'Browser': TestBrowser})
     def make_suite(filename, package=None):
         optionflags = (doctest.ELLIPSIS | doctest.REPORT_NDIFF |
                        doctest.NORMALIZE_WHITESPACE |
                        doctest.REPORT_ONLY_FIRST_FAILURE)
         suite = FunctionalDocFileSuite(filename, package=package,
                                        optionflags=optionflags,
-                                       globs={'analyze': analyze,
-                                              'Browser': TestBrowser})
+                                       globs=extra_globs)
         return suite
     return collect_txt_ftests(package=package, level=level,
                               layer=layer, filenames=filenames,
