@@ -42,7 +42,6 @@ import lxml.doctestcompare
 import lxml.etree
 
 from zope.app.wsgi import WSGIPublisherApplication
-from zope.app.server.wsgi import ServerType
 from zope.server.taskthreads import ThreadedTaskDispatcher
 from zope.server.http.commonaccesslogger import CommonAccessLogger
 from zope.server.http.wsgihttpserver import WSGIHTTPServer
@@ -73,7 +72,6 @@ except ImportError:
 
 
 try:
-    # selenium on python2.5 throws a SyntaxError
     from selenium.webdriver.remote.webelement import WebElement \
             as SimpleWebElement
 
@@ -84,13 +82,10 @@ try:
             return selenium.webdriver.firefox.webdriver.WebDriver()
         selenium_enabled = True
 
-except (ImportError, SyntaxError):
-    SimpleWebElement = object
-
-try:
     from selenium.common.exceptions import NoSuchElementException
     from selenium.common.exceptions import TimeoutException
 except ImportError:
+    SimpleWebElement = object
     pass
 
 
@@ -873,6 +868,10 @@ class Downloads(object):
         tstamp = os.path.getctime(os.path.join(self.path, fname))
         return tstamp
 
+    def _size(self, fname):
+        size = os.path.getsize(os.path.join(self.path, fname))
+        return size
+
     def _wrap(self, fname):
         url = None
         if getattr(self.layer.config, 'downloads_url', None):
@@ -886,6 +885,12 @@ class Downloads(object):
         if self.path is None:
             return
         for name in os.listdir(self.path):
+            # unfinished download
+            if name.endswith('.crdownload') or name.endswith('.part'):
+                continue
+            # empty file
+            if not self._size(name):
+                continue
             timestamp = self._created(name)
             if (name not in self.files):
                 # file is new:
@@ -1009,11 +1014,6 @@ class FTestWSGIHTTPServer(WSGIHTTPServer):
             self.port = port
 
 
-HTTPServerFactory = ServerType(FTestWSGIHTTPServer,
-                               WSGIPublisherApplication,
-                               CommonAccessLogger,
-                               0, True)
-
 DOCTEST_EXAMPLE_FILENAME_RE = re.compile(r'<doctest (?P<name>.+)\[(?P<examplenum>\d+)\]>$')
 
 
@@ -1158,7 +1158,6 @@ def make_testrunner_postmortem_patch(test):
 
 class SeleniumLayer(ZCMLLayer):
 
-    server_factory = HTTPServerFactory
     thread_count = 1
     ip = "127.0.0.1"
     port = 0
@@ -1187,9 +1186,13 @@ class SeleniumLayer(ZCMLLayer):
         self.setUpBrowserConfig()
         dispatcher = ThreadedTaskDispatcher()
         dispatcher.setThreadCount(self.thread_count)
-        self.server = self.server_factory.create(
-            'WSGI-HTTP', dispatcher, self.setup.db,
-            ip=self.ip, port=self.port)
+        application = WSGIPublisherApplication(self.setup.db)
+        self.server = FTestWSGIHTTPServer(application,
+                                          'WSGI-HTTP',
+                                          self.ip, self.port,
+                                          task_dispatcher=dispatcher,
+                                          verbose=True,
+                                          hit_log=CommonAccessLogger())
         self.thread = threading.Thread(target=self.poll_server)
         self.thread.setDaemon(True)
         self.thread.start()
